diff --git a/app/build.gradle b/app/build.gradle
index 8ee072b8..08f4861a 100644
--- a/app/build.gradle
+++ b/app/build.gradle
@@ -63,8 +63,8 @@ android {
renderscriptTargetApi 23
applicationId "com.kabouzeid.gramophone"
- versionCode 81
- versionName "0.9.50 PREVIEW 1"
+ versionCode 82
+ versionName "0.9.50 PREVIEW 2"
}
buildTypes {
release {
diff --git a/app/src/main/assets/changelog.html b/app/src/main/assets/phonograph-changelog.html
similarity index 94%
rename from app/src/main/assets/changelog.html
rename to app/src/main/assets/phonograph-changelog.html
index 19b5a785..4a893a81 100644
--- a/app/src/main/assets/changelog.html
+++ b/app/src/main/assets/phonograph-changelog.html
@@ -25,10 +25,22 @@
You can view the changelog dialog again at any time from the about section.
-Version 0.9.50 PREVIEW 1
+Version 0.9.50 PREVIEW 2
You can always downgrade by downloading the old apk from APKMirror for example.
+
+ - NEW:Added option to disable the blurred album cover on the lockscreen.
+ - IMPROVEMENT: Finished the menu for the current song in the playing queue.
+ - IMPROVEMENT: Better drag and drop inside playlists.
+ - IMPROVEMENT: Synced translations.
+ - IMPROVEMENT: Some other minor improvements.
+ - FIX: Colored navigation bar issue.
+ - FIX: Wrong titles shown in the toolbar when selecting an item.
+
+
+Version 0.9.50 PREVIEW 1
+
- NEW: All new now playing screen. The old one will be available again in the full
update as an option.
diff --git a/app/src/main/java/com/kabouzeid/gramophone/dialogs/ChangelogDialog.java b/app/src/main/java/com/kabouzeid/gramophone/dialogs/ChangelogDialog.java
index e3da513d..37416654 100644
--- a/app/src/main/java/com/kabouzeid/gramophone/dialogs/ChangelogDialog.java
+++ b/app/src/main/java/com/kabouzeid/gramophone/dialogs/ChangelogDialog.java
@@ -66,9 +66,9 @@ public class ChangelogDialog extends LeakDetectDialogFragment {
final WebView webView = (WebView) customView.findViewById(R.id.web_view);
try {
// Load from changelog.html in the assets folder
StringBuilder buf = new StringBuilder();
- InputStream json = getActivity().getAssets().open("changelog.html");
+ InputStream json = getActivity().getAssets().open("phonograph-changelog.html");
BufferedReader in = new BufferedReader(new InputStreamReader(json, "UTF-8"));
String str;
while ((str = in.readLine()) != null)
@@ -66,9 +66,9 @@ public class ChangelogDialog extends LeakDetectDialogFragment {
final WebView webView = (WebView) customView.findViewById(R.id.web_view);
try {
- // Load from changelog.html in the assets folder
+ // Load from phonograph-changelog.html in the assets folder
StringBuilder buf = new StringBuilder();